#include "StdAfx.h"
#include "SendMemoButtons.h"
#include "CommonFunction.h"

const DWORD TEXT_COLOR = 0x5e5f6d;

DUI_BEGIN_MESSAGE_MAP(COKCancelButtons, EmbeddedDUIInMFCWindow, FALSE)
DUI_ON_MSGTYPE(DUI_MSGTYPE_WINDOWINIT, OnPrepare)

DUI_ON_CLICK_CTRNAME(_T("btn_ok"), _OnNotifyBtnOKClick)
DUI_ON_CLICK_CTRNAME(_T("btn_cancle"), _OnNotifyBtnCancelClick)
DUI_END_MESSAGE_MAP()

COKCancelButtons::COKCancelButtons( CWnd* pParent, IOKCancelButtonsCallBack* pCallBack )
:EmbeddedDUIInMFCWindow (pParent)
{
	m_strButtonOK.Empty();
	m_strButtonCancel.Empty();
	m_pBtnCancel = NULL;
	m_pBtnOK = NULL;
	m_pCallBack = pCallBack;
}

COKCancelButtons::~COKCancelButtons(void)
{
}

LPCTSTR COKCancelButtons::GetWindowClassName() const
{
	return _T("SendMemoButtons");
}


void COKCancelButtons::SetButtonText( LPCTSTR strButtonOK, LPCTSTR strButtoCancel )
{
	m_strButtonOK = strButtonOK;
	m_strButtonCancel = strButtoCancel;
}


void COKCancelButtons::OnPrepare( TNotifyUI& msg )
{
	m_pBtnCancel = static_cast<CButtonUI*>(m_PaintManager.FindControl(_T("btn_cancle")));
	ASSERT(m_pBtnCancel);

	if(m_pBtnCancel != NULL)
	{
		m_pBtnCancel->SetFont(GetDefaultFontIndex());
		m_pBtnCancel->SetText(m_strButtonCancel);
		m_pBtnCancel->SetTextColor(TEXT_COLOR);
	}

	m_pBtnOK = static_cast<CButtonUI*>(m_PaintManager.FindControl(_T("btn_ok")));
	ASSERT(m_pBtnOK);

	if(m_pBtnOK != NULL)
	{
		m_pBtnOK->SetFont(GetDefaultFontIndex());
		m_pBtnOK->SetText(m_strButtonOK);
		m_pBtnOK->SetTextColor(TEXT_COLOR);
	}


}


void COKCancelButtons::SetClientRect( CRect rc )
{
	MoveWindow(GetHWND(), rc.left, rc.top, rc.Width(), rc.Height(), TRUE);
}

void COKCancelButtons::LoadSkin()
{
	m_PaintManager.Init(m_hWnd);
	CDialogBuilder dlgBuilder;
	CDialogBuilderCallback<COKCancelButtons> cb(this);
	CControlUI* pRoot = dlgBuilder.Create(_T("SendMemoButtons.xml"), (UINT)0,  &cb, &m_PaintManager);
	ASSERT(pRoot);
	m_PaintManager.AttachDialog(pRoot);
	m_PaintManager.AddNotifier(this);
}	

void COKCancelButtons::SetButtonReadOnly( bool bReadOnly, BUTTONS button )
{
	if(button == OK || button == All)
	{
		ASSERT(m_pBtnOK);

		if(m_pBtnOK)
		{
			m_pBtnOK->SetEnabled(bReadOnly);
		}
		
	}

	if(button == Cancle || button == All)
	{
		ASSERT(m_pBtnCancel);

		if(m_pBtnCancel)
		{
			m_pBtnCancel->SetEnabled(bReadOnly);
		}
		
	}
}


bool COKCancelButtons::GetButtonReadOnly( BUTTONS button )
{
	ASSERT( button != All);

	bool bRet = false;
	if(button == OK)
	{
		ASSERT(m_pBtnOK != NULL);
		if(m_pBtnOK != NULL)
		{
			bRet = m_pBtnOK->IsEnabled();
		}
	}

	if(button == Cancle)
	{
		ASSERT(m_pBtnCancel != NULL);
		if(m_pBtnCancel != NULL)
		{
			bRet = m_pBtnCancel->IsEnabled();
		}
	}

	return bRet;
}
DuiLib::CDuiString COKCancelButtons::GetSkinFile()
{
	return _T("SendMemoButtons.xml");
}

DuiLib::CDuiString COKCancelButtons::GetSkinFolder()
{
	return _T("skin\\nTalkRes");
}

void COKCancelButtons::OnFinalMessage( HWND hWnd )
{
	WindowImplBase::OnFinalMessage(hWnd);
}

CControlUI* COKCancelButtons::CreateControl( LPCTSTR pstrClass )
{
	return NULL;
}


void COKCancelButtons::_OnNotifyBtnOKClick( TNotifyUI& msg )
{
	ASSERT(m_pCallBack);
	if(m_pCallBack)
	{
		m_pCallBack->OnButtonClicked(OK);
	}
}

void COKCancelButtons::_OnNotifyBtnCancelClick( TNotifyUI& msg )
{
	ASSERT(m_pCallBack);
	if(m_pCallBack)
	{
		m_pCallBack->OnButtonClicked(Cancle);
	}
}

LRESULT COKCancelButtons::OnNcHitTest( UINT uMsg, WPARAM wParam, LPARAM lParam, BOOL& bHandled )
{
	return HTCLIENT;
}
